@@ -6,6 +6,7 @@
   (struct)
   (parameters)
   (tuple_type)
+  (struct_type)
   (call_expression)
   (switch_case)
 ] @indent
@@ -21,3 +22,4 @@
 (union_declaration "}" @outdent)
 (struct_declaration "}" @outdent)
 (struct "}" @outdent)
+(struct_type "}" @outdent)
