@@ -42,3 +42,15 @@
 ; Comments
 (comment) @comment.inside 
 (comment)+ @comment.around
+
+(pair
+  (_) @entry.inside) @entry.around
+
+(array
+  (_) @entry.around)
+
+(string_array
+  (_) @entry.around)
+
+(symbol_array
+  (_) @entry.around)
