@@ -1,8 +1,12 @@
-(ERROR) @error
-
 (line_comment) @comment
 
-(identifier) @variable
+(identifier) @function
+
+(labeled_rule
+  (identifier) @type)
+
+(node_rule
+  (identifier) @variable.parameter)
 
 (token) @string
 
